#!/usr/bin/tclsh
#clientAPI.tcl
#Maintained by W.Yang
#An interface layer for application to connect database handler.
#The following API is provided:
#
#OpenConnection host port
#CloseConnection sock
#OpenDB sock host username password dbname
#NewProject sock projectname
#NewJob sock projectname jobname
#SetData sock jobid name value
#GetData sock jobid name
#ListProjects sock
#ListJobs sock projectid
#ListItems sock jobid
#GetProject sock projectname
#Version sock
#
#CVS Id $Id: clientAPI.tcl,v 1.4 2005/09/21 14:09:04 wy45 Exp $

proc OpenConnection { host port } {
    set sock [ socket $host $port ]
    fconfigure $sock -buffering line
    return $sock
}

proc CloseConnection { sock } {
    set data "<db_request><command>CloseDB</command></db_request>"
    puts $sock $data
    flush $sock
    gets $sock result
    close $sock
    return $result
}

proc OpenDB { sock host username password dbname } {
    set data "<db_request><command>OpenDB</command><argument>$host</argument><argument>$username</argument><argument>$password</argument><argument>$dbname</argument></db_request>"
    puts $sock $data
    flush $sock
    gets $sock result
    return $result
}

proc IsOpen { sock } {
    set data "<db_request><command>IsOpen</command></db_request>"
    puts $sock $data
    flush $sock
    gets $sock result
    return $result
}

proc NewProject { sock projectname } {
    if { $projectname == "" } {
       set result  "<db_response><status>failed</status><result>project name cannot be empty!</result></db_response>"
       return result
    } else {
       set data "<db_request><command>NewProject</command><argument>$projectname</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result       
    }
}

proc NewJob { sock projectname jobName } {
    if { $projectname == "" || $jobName == "" } {
       return  "<db_response><status>failed</status><result>project id or job name cannot be empty!</result></db_response>"
    }  else { 
       set data "<db_request><command>NewJob</command><argument>$projectname</argument><argument>$jobName</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result  
  
    }
}

proc SetData { sock jobid name value } {
       set data "<db_request><command>SetData</command><argument>$jobid</argument><argument>$name</argument><argument>$value</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result      
    }

proc GetData { sock jobid name } {
       set data "<db_request><command>GetData</command><argument>$jobid</argument><argument>$name</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result    
   }

proc ListProjects { sock } {
       set data "<db_request><command>ListProjects</command></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result  
    }

proc ListJobs { sock projectname } {
       set data "<db_request><command>ListJobs</command><argument>$projectname</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result  
    }

proc ListItems { sock jobid } {
       set data "<db_request><command>ListItems</command><argument>$jobid</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result  
    }

proc GetProject { sock projectname } {
       set data "<db_request><command>GetProject</command><argument>$projectname</argument></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result    
   }

proc Version { sock } {
       set data "<db_request><command>Version</command></db_request>"
       puts $sock $data
       flush $sock
       gets $sock result
       return $result  
    }

